using System;
using System.Collections.Generic;
using System.IO;
using UnityEngine;
using UnityEngine.Events;

namespace Armor
{
    public class Mod
    {
        public static void Main()
        {
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"), //item to derive from
                    NameOverride = "Medieval Armor Set - FA", //new item name with a suffix to assure it is globally unique
                    NameToOrderByOverride = "A - FA",
                    DescriptionOverride = "Medieval armor set. Great against swords, useless against bullets. Very heavy.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("upperchestplate.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("upperchestplate.png"); //get the SpriteRenderer and replace its sprite with a custom one

                        int PartCount = 9;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();
                        
                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 0;
                        prop.sprite = ModAPI.LoadSprite("upperchestplate.png");
                        prop.armorPoints = 5;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("lowerchestplate.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorPoints = 5;

                        armProp[1].sprite = ModAPI.LoadSprite("faulds.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorPoints = 5;

                        armProp[2].sprite = ModAPI.LoadSprite("medievalfauld.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorPoints = 5;

                        armProp[3].sprite = ModAPI.LoadSprite("greave.png");
                        armProp[3].armorPiece = "LowerLeg";
                        armProp[3].clone = true;
                        armProp[3].armorPoints = 5;

                        armProp[4].sprite = ModAPI.LoadSprite("foot.png");
                        armProp[4].armorPiece = "Foot";
                        armProp[4].armorPoints = 5;
                        armProp[4].clone = true;

                        armProp[5].sprite = ModAPI.LoadSprite("leatherPadding.png");
                        armProp[5].armorPiece = "UpperArm";
                        armProp[5].armorPoints = 5;
                        armProp[5].clone = true;

                        armProp[6].sprite = ModAPI.LoadSprite("medievalgauntlet.png");
                        armProp[6].armorPiece = "LowerArm";
                        armProp[6].armorPoints = 5;
                        armProp[6].clone = true;

                        armProp[7].sprite = ModAPI.LoadSprite("crusaderhelmet.png");
                        armProp[7].armorPiece = "Head";
                        armProp[7].armorPoints = 5;

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"), //item to derive from
                    NameOverride = "Kevlar Vest - FA", //new item name with a suffix to assure it is globally unique
                    NameToOrderByOverride = "A1 - FA",
                    DescriptionOverride = "Simple kevlar vest. Not very resistant, but will protect from most pistol caliber weapons.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("kevlarView.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("level1top.png"); //get the SpriteRenderer and replace its sprite with a custom one

                        int PartCount = 2;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();
                        Vector3 offset = new Vector3(.01f, 0);
                        Vector3 scaleOffset = new Vector3(.05f, .05f);

                        ArmorProperties prop = new ArmorProperties();
                        
                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 2;
                        prop.sprite = ModAPI.LoadSprite("level1top.png");
                        prop.offset = offset;
                        prop.scaleOffset = scaleOffset;
                        prop.armorPoints = 20;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("level1middle.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 2;
                        armProp[0].offset = offset;
                        armProp[0].scaleOffset = scaleOffset;
                        armProp[0].armorPoints = 15;

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"), //item to derive from
                    NameOverride = "Ballistic Plate Carrier - FA", //new item name with a suffix to assure it is globally unique
                    NameToOrderByOverride = "A2 - FA",
                    DescriptionOverride = "Simple plate carrier. Significantly better than kevlar.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("plateView.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("level2top.png"); //get the SpriteRenderer and replace its sprite with a custom one

                        int PartCount = 2;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();
                        Vector3 offset = new Vector3(.025f, 0);
                        Vector3 scaleOffset = new Vector3(.03f, 0);

                        ArmorProperties prop = new ArmorProperties();
                        
                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("level2top.png");
                        prop.offset = offset;
                        prop.scaleOffset = scaleOffset;
                        prop.armorPoints = 50;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("level2middle.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 3;
                        armProp[0].offset = offset;
                        armProp[0].scaleOffset = scaleOffset;
                        armProp[0].armorPoints = 45;

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"), //item to derive from
                    NameOverride = "Ballistic Accessories - FA", //new item name with a suffix to assure it is globally unique
                    NameToOrderByOverride = "A5 - FA",
                    DescriptionOverride = "Some ballistic accessories. Contains a ballistic mask, riot helmet, and a pelvis panel.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("accessoryView.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("ballisticmask.png"); //get the SpriteRenderer and replace its sprite with a custom one

                        int PartCount = 3;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();
                        
                        prop.armorPiece = "Head";
                        prop.armorTier = 2;
                        prop.sprite = ModAPI.LoadSprite("ballisticmask.png");
                        Vector2[] points1 = new Vector2[4];
                        points1[0] = new Vector3(.2f, .2f);
                        points1[1] = new Vector3(-.025f, .2f);
                        points1[2] = new Vector3(-.025f, -.2f);
                        points1[3] = new Vector3(.2f, -.2f);
                        prop.customCollider = true;
                        prop.points = points1;
                        prop.armorPoints = 40;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("riotnovisor.png");
                        armProp[0].armorPiece = "Head";
                        armProp[0].armorTier = 2;
                        armProp[0].armorPoints = 35;
                        Vector2[] points = new Vector2[6];
                        points[0] = new Vector3(-.2f, .2f);
                        points[1] = new Vector3(-.2f, -.2f);
                        points[2] = new Vector3(.03f, -.2f);
                        points[3] = new Vector3(.03f, .06f);
                        points[4] = new Vector3(.2f, .06f);
                        points[5] = new Vector3(.2f, .2f);
                        armProp[0].customCollider = true;
                        armProp[0].points = points;
                        armProp[0].hasVisor = true;
                        armProp[0].visorSprite = ModAPI.LoadSprite("riotvisor.png");
                        armProp[0].visorPoints = 30;
                        armProp[0].visorTier = 2;
                        armProp[0].visorPosition = new Vector3(0, 0.095f);
                        
                        armProp[1].sprite = ModAPI.LoadSprite("pelvispanel.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 2;
                        armProp[1].armorPoints = 25;

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }
                    }
                }
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"), //item to derive from
                    NameOverride = "Military Armor Set - FA", //new item name with a suffix to assure it is globally unique
                    NameToOrderByOverride = "A3 - FA",
                    DescriptionOverride = "Military-grade armor. Colored with a simple desert shade.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("militaryThumb.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("militarytop.png"); //get the SpriteRenderer and replace its sprite with a custom one

                        int PartCount = 6;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();
                        Vector3 offset = new Vector3(.025f, 0);
                        Vector3 scaleOffset = new Vector3(.01f, .01f);
                        
                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 3;
                        prop.sprite = ModAPI.LoadSprite("militarytop.png");
                        prop.offset = offset;
                        prop.scaleOffset = scaleOffset;
                        prop.armorPoints = 60;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].sprite = ModAPI.LoadSprite("militarymiddle.png");
                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].offset = offset;
                        armProp[0].armorTier = 3;
                        armProp[0].scaleOffset = scaleOffset;
                        armProp[0].armorPoints = 60;

                        armProp[1].sprite = ModAPI.LoadSprite("militarybottom.png");
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].offset = offset;
                        armProp[1].armorTier = 3;
                        armProp[1].scaleOffset = scaleOffset;
                        armProp[1].armorPoints = 35;

                        armProp[2].sprite = ModAPI.LoadSprite("thighpad.png");
                        armProp[2].armorPiece = "UpperLeg";
                        armProp[2].clone = true;
                        armProp[2].armorTier = 2;
                        armProp[2].offset = new Vector3(0, .1f);
                        armProp[2].armorPoints = 15;

                        armProp[3].sprite = ModAPI.LoadSprite("shoulderpad.png");
                        armProp[3].armorPiece = "UpperArm";
                        armProp[3].clone = true;
                        armProp[3].armorTier = 2;
                        armProp[3].offset = new Vector3(0, .1f);
                        armProp[3].armorPoints = 20;

                        armProp[4].sprite = ModAPI.LoadSprite("helmet.png");
                        armProp[4].armorPiece = "Head";
                        armProp[4].armorTier = 2;
                        armProp[4].scaleOffset = new Vector3(.075f, .075f);
                        armProp[4].armorPoints = 30;
                        Vector2[] points = new Vector2[6];
                        points[0] = new Vector3(-.2f, .2f);
                        points[1] = new Vector3(-.2f, -.2f);
                        points[2] = new Vector3(.03f, -.2f);
                        points[3] = new Vector3(.03f, .06f);
                        points[4] = new Vector3(.2f, .06f);
                        points[5] = new Vector3(.2f, .2f);
                        armProp[4].customCollider = true;
                        armProp[4].points = points;

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );
            ModAPI.Register(
                new Modification()
                {
                    OriginalItem = ModAPI.FindSpawnable("Rod"), //item to derive from
                    NameOverride = "Juggernaut Armor Set - FA", //new item name with a suffix to assure it is globally unique
                    NameToOrderByOverride = "A4 - FA",
                    DescriptionOverride = "Full armor set that provides heavy protection. Full set alone protects everything above the legs but the head. Has a colorless varient.", //new item description
                    CategoryOverride = ModAPI.FindCategory("Entities"), //new item category
                    ThumbnailOverride = ModAPI.LoadSprite("juggerview.png"), //new item thumbnail (relative path)
                    AfterSpawn = (Instance) => //all code in the AfterSpawn delegate will be executed when the item is spawned
                    {
                        Instance.GetComponent<SpriteRenderer>().sprite = ModAPI.LoadSprite("kevlaruppervestc.png"); //get the SpriteRenderer and replace its sprite with a custom one

                        int PartCount = 10;

                        if (!Instance.GetComponent<ArmorBehaviour>())
                            Instance.AddComponent<ArmorBehaviour>();

                        ArmorBehaviour armor = Instance.GetComponent<ArmorBehaviour>();

                        ArmorProperties prop = new ArmorProperties();
                        
                        prop.armorPiece = "UpperBody";
                        prop.armorTier = 4;
                        prop.sprite = ModAPI.LoadSprite("kevlaruppervestc.png");
                        prop.graySprite = "kevlaruppervest.png";
                        prop.armorPoints = 100;

                        armor.prop = prop;
                        armor.SetProperties();

                        ArmorProperties[] armProp = new ArmorProperties[PartCount - 1];

                        armProp[0].armorPiece = "MiddleBody";
                        armProp[0].armorTier = 4;
                        armProp[0].sprite = ModAPI.LoadSprite("kevlarmiddlevestc.png");
                        armProp[0].graySprite = "kevlarmiddlevest.png";
                        armProp[0].armorPoints = 100;
                        
                        armProp[1].armorPiece = "LowerBody";
                        armProp[1].armorTier = 4;
                        armProp[1].sprite = ModAPI.LoadSprite("kevlarlowervestc.png");
                        armProp[1].graySprite = "kevlarlowervest.png";
                        armProp[1].offset = new Vector3(0, .07f);
                        armProp[1].armorPoints = 80;

                        armProp[2].armorPiece = "LowerBody";
                        armProp[2].armorTier = 4;
                        armProp[2].sprite = ModAPI.LoadSprite("kevlarhippadc.png");
                        armProp[2].graySprite = "kevlarhippad.png";
                        armProp[2].scaleOffset = new Vector3(0.01f, 0.01f);
                        armProp[2].armorPoints = 20;

                        armProp[3].armorPiece = "LowerBody";
                        armProp[3].armorTier = 4;
                        armProp[3].sprite = ModAPI.LoadSprite("kevlarpelvispanelc.png");
                        armProp[3].graySprite = "kevlarpelvispanel.png";
                        //armProp[3].offset = new Vector3(0, -.02f);
                        armProp[3].armorPoints = 50;

                        armProp[4].armorPiece = "UpperLeg";
                        armProp[4].armorTier = 4;
                        armProp[4].sprite = ModAPI.LoadSprite("kevlarthighpadc.png");
                        armProp[4].graySprite = "kevlarthighpad.png";
                        armProp[4].offset = new Vector3(0, .1f);
                        armProp[4].scaleOffset = new Vector3(0.05f, 0.05f);
                        armProp[4].clone = true;
                        armProp[4].armorPoints = 40;

                        armProp[5].armorPiece = "UpperArm";
                        armProp[5].armorTier = 4;
                        armProp[5].sprite = ModAPI.LoadSprite("kevlarshoulderpadc.png");
                        armProp[5].graySprite = "kevlarshoulderpad.png";
                        armProp[5].offset = new Vector3(0, .1f);
                        armProp[5].scaleOffset = new Vector3(0.05f, 0.05f);
                        armProp[5].clone = true;
                        armProp[5].armorPoints = 45;

                        armProp[6].armorPiece = "LowerArm";
                        armProp[6].armorTier = 4;
                        armProp[6].sprite = ModAPI.LoadSprite("kevlararmpadc.png");
                        armProp[6].graySprite = "kevlararmpad.png";
                        armProp[6].offset = new Vector3(0, .05f);
                        armProp[6].scaleOffset = new Vector3(0.05f, 0.05f);
                        armProp[6].clone = true;
                        armProp[6].armorPoints = 20;

                        armProp[7].armorPiece = "UpperBody";
                        armProp[7].armorTier = 4;
                        armProp[7].sprite = ModAPI.LoadSprite("kevlarupperplatec.png");
                        armProp[7].graySprite = "kevlarupperplate.png";
                        armProp[7].armorPoints = 20;

                        armProp[8].armorPiece = "MiddleBody";
                        armProp[8].armorTier = 4;
                        armProp[8].sprite = ModAPI.LoadSprite("kevlarlowerplatec.png");
                        armProp[8].graySprite = "kevlarlowerplate.png";
                        armProp[8].armorPoints = 20;

                        if (armor.spawn)
                        {
                            armor.SetPieces = new ArmorBehaviour[PartCount - 1];
                            armor.SpawnOtherParts(armProp);
                        }

                        Instance.FixColliders();
                    }
                }
            );
        }
    }
}
